@@ -9,6 +9,7 @@ from pydantic import BaseModel
 
 class MagicException(Exception):
     def __init__(self, message: str, json_response: dict = None):
+        print(f"*MagicException*: {message=}")
         self.status_code: int = 452
         self.message: str = message
         self.json_response: dict = json_response or {}
@@ -19,6 +20,8 @@ class MagicException(Exception):
         json_response: dict = {}
 
     def to_model(self) -> MagicExceptionModel:
+        if self.message and not type(self.message) == str:
+            self.message = str(self.message)
         return self.MagicExceptionModel(**self.__dict__)
 
     @classmethod
